diff --git a/force_bdss/factory_registry_plugin.py b/force_bdss/factory_registry_plugin.py
index 3dc765657afcea4a303e4ca2d0ff38c775dfeab0..2e3d2b1f375b05b2dd8b38c2560040d7b0f994da 100644
--- a/force_bdss/factory_registry_plugin.py
+++ b/force_bdss/factory_registry_plugin.py
@@ -3,22 +3,11 @@ from envisage.plugin import Plugin
 from traits.api import List
 
 from force_bdss.ids import ExtensionPointID
-<<<<<<< HEAD:force_bdss/bundle_registry_plugin.py
-from force_bdss.notification_listeners.i_notification_listener_bundle import \
-    INotificationListenerBundle
-from .data_sources.i_data_source_bundle import (
-    IDataSourceBundle)
-from .kpi.i_kpi_calculator_bundle import IKPICalculatorBundle
-from .mco.i_mco_bundle import (
-    IMCOBundle
-=======
+from force_bdss.notifier.i_notifier_factory import INotifierFactory
 from .data_sources.i_data_source_factory import (
     IDataSourceFactory)
 from .kpi.i_kpi_calculator_factory import IKPICalculatorFactory
-from .mco.i_mco_factory import (
-    IMCOFactory
->>>>>>> master:force_bdss/factory_registry_plugin.py
-)
+from .mco.i_mco_factory import IMCOFactory
 
 
 FACTORY_REGISTRY_PLUGIN_ID = "force.bdss.plugins.factory_registry"
@@ -53,20 +42,14 @@ class FactoryRegistryPlugin(Plugin):
         List(IKPICalculatorFactory),
         id=ExtensionPointID.KPI_CALCULATOR_FACTORIES)
 
-<<<<<<< HEAD:force_bdss/bundle_registry_plugin.py
-    notification_listener_bundles = ExtensionPoint(
-        List(INotificationListenerBundle),
-        id=ExtensionPointID.NOTIFICATION_LISTENER_BUNDLE
+    notifier_factories = ExtensionPoint(
+        List(INotifierFactory),
+        id=ExtensionPointID.NOTIFIER_FACTORY
     )
 
-    def data_source_bundle_by_id(self, id):
-        """Finds a given data source bundle by means of its id.
-        The ID is as obtained by the function bundle_id() in the
-=======
     def data_source_factory_by_id(self, id):
         """Finds a given data source factory by means of its id.
         The ID is as obtained by the function factory_id() in the
->>>>>>> master:force_bdss/factory_registry_plugin.py
         plugin api.
 
         Parameters
@@ -158,7 +141,7 @@ class FactoryRegistryPlugin(Plugin):
         raise KeyError("Requested MCO parameter {}:{} but don't know"
                        " how to find it.".format(mco_id, parameter_id))
 
-    def notification_listener_bundle_by_id(self, id):
+    def notifier_factory_by_id(self, id):
         """Finds a given notification listener by means of its id.
         The ID is as obtained by the function bundle_id() in the
         plugin api.
@@ -172,10 +155,10 @@ class FactoryRegistryPlugin(Plugin):
         ------
         KeyError: if the entry is not found.
         """
-        for nl in self.notification_listener_bundles:
+        for nl in self.notifier_factories:
             if nl.id == id:
                 return nl
 
         raise KeyError(
-            "Requested notification listener {} but don't know how "
+            "Requested notifier_factory {} but don't know how "
             "to find it.".format(id))
diff --git a/force_bdss/mco/base_mco.py b/force_bdss/mco/base_mco.py
index bea4ebca12706a569e335ad428c4d2cd8cc80d03..72b2b4567bc64642e90104561a8ab3e784d0ffcc 100644
--- a/force_bdss/mco/base_mco.py
+++ b/force_bdss/mco/base_mco.py
@@ -13,17 +13,13 @@ class BaseMCO(ABCHasStrictTraits):
     #: A reference to the factory
     factory = Instance(IMCOFactory)
 
-<<<<<<< HEAD
     started = Event()
 
     finished = Event()
 
     progress = Event()
 
-    def __init__(self, bundle, *args, **kwargs):
-=======
     def __init__(self, factory, *args, **kwargs):
->>>>>>> master
         """Initializes the MCO.
 
         Parameters
diff --git a/force_bdss/notification_listeners/i_notification_listener_bundle.py b/force_bdss/notification_listeners/i_notification_listener_bundle.py
index 2693dec9cbd4fea31233d57708e82212be0f94c3..bb3a49d6a867e2a45a12052edae8e9d2fc5ef8e7 100644
--- a/force_bdss/notification_listeners/i_notification_listener_bundle.py
+++ b/force_bdss/notification_listeners/i_notification_listener_bundle.py
@@ -2,11 +2,11 @@ from traits.api import Interface, String, Instance
 from envisage.plugin import Plugin
 
 
-class INotificationListenerBundle(Interface):
-    """Envisage required interface for the BaseNotificationListenerBundle.
+class INotifierFactory(Interface):
+    """Envisage required interface for the BaseNotifierFactory.
     You should not need to use this directly.
 
-    Refer to the BaseNotificationListenerBundle for documentation.
+    Refer to the BaseNotifier for documentation.
     """
     id = String()